import { Component, OnInit, Input } from '@angular/core';
import {
  EventType,
  Info,
  EventJson,
  RenameRoomEventJson,
  GuideForRoomTimerChangedEventJson,
  JoinEventJson
} from '@ucap/protocol-event';
import { TranslateService } from '@ucap/ng-ui-organization';

@Component({
  selector: 'ucap-chat-message-box-information',
  templateUrl: './information.component.html',
  styleUrls: ['./information.component.scss']
})
export class InformationComponent implements OnInit {
  @Input()
  message: Info<EventJson>;

  @Input()
  senderName?: string;

  EventType = EventType;

  constructor(private translateService: TranslateService) {}

  ngOnInit() {}

  getI18nForSir(names: string | string[]) {
    if (Array.isArray(names)) {
      const inviter: string[] = [];

      // names.forEach((userName, idx) => {
      //   inviter.push(
      //     this.translateService.instant('common.messages.sirWith', {
      //       sir: userName
      //     })
      //   );
      // });
      names.forEach((userName, idx) => {
        inviter.push(userName);
      });

      return inviter.join(',');
    } else {
      // return this.translateService.instant('common.messages.sirWith', {
      //   sir: names
      // });
      return names;
    }
  }

  getOwnerForJoinEventJson() {
    return (this.message.sentMessageJson as JoinEventJson).owner;
  }
  getInviterForJoinEventJson() {
    return (this.message.sentMessageJson as JoinEventJson).inviter;
  }
  getCalcTimerForGuideForRoomTimerChanged() {
    const millisec =
      Number(
        (this.message.sentMessageJson as GuideForRoomTimerChangedEventJson).time
      ) * 1000;
    // const langs = this.translateService.instant([
    //   'common.units.hourFrom',
    //   'common.units.minute',
    //   'common.units.second'
    // ]);

    // switch (millisec) {
    //   case 5000:
    //     return `5 ${langs['common.units.second']}`;
    //   case 10000:
    //     return `10 ${langs['common.units.second']}`;
    //   case 30000:
    //     return `30 ${langs['common.units.second']}`;
    //   case 60000:
    //     return `1 ${langs['common.units.minute']}`;
    //   case 300000:
    //     return `5 ${langs['common.units.minute']}`;
    //   case 600000:
    //     return `10 ${langs['common.units.minute']}`;
    //   case 1800000:
    //     return `30 ${langs['common.units.minute']}`;
    //   case 3600000:
    //     return `1 ${langs['common.units.hourFrom']}`;
    //   case 21600000:
    //     return `6 ${langs['common.units.hourFrom']}`;
    //   case 43200000:
    //     return `12 ${langs['common.units.hourFrom']}`;
    //   case 86400000:
    //     return `24 ${langs['common.units.hourFrom']}`;
    //   default:
    //     return `0 ${langs['common.units.second']}`;
    // }

    const langs = ['초', '분', '시간'];

    switch (millisec) {
      case 5000:
        return `5 ${langs[0]}`;
      case 10000:
        return `10 ${langs[0]}`;
      case 30000:
        return `30 ${langs[0]}`;
      case 60000:
        return `1 ${langs[1]}`;
      case 300000:
        return `5 ${langs[1]}`;
      case 600000:
        return `10 ${langs[1]}`;
      case 1800000:
        return `30 ${langs[1]}`;
      case 3600000:
        return `1 ${langs[2]}`;
      case 21600000:
        return `6 ${langs[2]}`;
      case 43200000:
        return `12 ${langs[2]}`;
      case 86400000:
        return `24 ${langs[2]}`;
      default:
        return `0 ${langs[0]}`;
    }
  }

  getRequesterForRenameRoom() {
    return (this.message.sentMessageJson as RenameRoomEventJson).requester;
  }
  getRoomNameForRenameRoom() {
    return (this.message.sentMessageJson as RenameRoomEventJson).roomName;
  }
}
