import { Subject } from 'rxjs';

import {
  Component,
  OnInit,
  OnDestroy,
  ChangeDetectionStrategy,
  ChangeDetectorRef,
  Output,
  EventEmitter
} from '@angular/core';

import { UserInfo } from '@ucap/protocol-sync';
import { MatChipSelectionChange, MatChipEvent } from '@angular/material/chips';

export interface ProfileSelection {
  userInfo: UserInfo;
  color?: string;
  selectable?: boolean;
  selected?: boolean;
  removable?: boolean;
}

@Component({
  selector: 'ucap-organization-profile-selection-01',
  templateUrl: './profile-selection-01.component.html',
  styleUrls: ['./profile-selection-01.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class ProfileSelection01Component implements OnInit, OnDestroy {
  @Output()
  selectionChange: EventEmitter<{
    selected: boolean;
    userInfo: UserInfo;
  }> = new EventEmitter();

  @Output()
  removed: EventEmitter<UserInfo> = new EventEmitter();

  // tslint:disable-next-line: variable-name
  _profileSelectionList: ProfileSelection[] = [];

  private ngOnDestroySubject: Subject<void>;

  constructor(private changeDetectorRef: ChangeDetectorRef) {}

  ngOnInit(): void {
    this.ngOnDestroySubject = new Subject();
  }

  ngOnDestroy(): void {
    if (!!this.ngOnDestroySubject) {
      this.ngOnDestroySubject.next();
      this.ngOnDestroySubject.complete();
    }
  }

  addProfileSelection(profileSelectionList: ProfileSelection[]): void {
    if (!profileSelectionList || 0 === profileSelectionList.length) {
      return;
    }

    profileSelectionList.forEach((v) => {
      const i = this.indexOfProfileSelection(v);
      if (-1 === i) {
        this._profileSelectionList.push(v);
      }
    });
  }

  removeProfileSelection(profileSelectionList: ProfileSelection[]): void {
    if (!profileSelectionList || 0 === profileSelectionList.length) {
      return;
    }

    profileSelectionList.forEach((v) => {
      const i = this.indexOfProfileSelection(v);
      if (-1 < i) {
        this._profileSelectionList.splice(i, 1);
      }
    });
  }

  _onSelectionChange(event: MatChipSelectionChange, userInfo: UserInfo) {
    this.selectionChange.emit({
      selected: event.selected,
      userInfo
    });
  }

  _onRemoved(event: MatChipEvent, userInfo: UserInfo) {
    this.removed.emit(userInfo);
  }

  private indexOfProfileSelection(profileSelection: ProfileSelection): number {
    if (
      !this._profileSelectionList ||
      0 === this._profileSelectionList.length ||
      !profileSelection
    ) {
      return -1;
    }

    return this._profileSelectionList.findIndex(
      (v) => v.userInfo.seq === profileSelection.userInfo.seq
    );
  }
}
